@@ -27,7 +27,7 @@ def position_between_xz(min_x, max_x, min_z, max_z, pos) -> bool:
 
 
 def vector_inverse(vector: NDArray) -> NDArray:
-    inv_vec = np.copy(vector).astype('float32')
+    inv_vec = np.copy(vector).astype('float64')
     for i in range(len(vector)):
         if inv_vec[i] == 0:
             inv_vec[i] = EPSILON
@@ -43,3 +43,9 @@ def plane_y_distance(pos_a: NDArray, pos_b: NDArray):
 def sort_nearest_points_from_on_plane_y(ref_pos: NDArray, points: List[NDArray]) -> List[NDArray]:
     sorted_points = sorted(points, key=lambda point: plane_y_distance(point, ref_pos))
     return sorted_points
+
+
+def calculate_reflection_angle(tx_pos, ref_pos, rx_pos):
+    ref_tx_dir = normalize(tx_pos-ref_pos)
+    ref_rx_dir = normalize(rx_pos-ref_pos)
+    return vector_angle(ref_tx_dir, ref_rx_dir)/2
