@@ -6,8 +6,5 @@ class TestVersion(unittest.TestCase):
 
     def test_version(self):
         """Check Version from radio_gyms"""
-        self.assertEqual(radio_gyms.__version__, "0.1.1")
+        self.assertEqual(radio_gyms.__version__, "0.2.0")
 
-
-if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
